summaryrefslogtreecommitdiffstats
path: root/board/sandbox/hostfile.c
diff options
context:
space:
mode:
Diffstat (limited to 'board/sandbox/hostfile.c')
-rw-r--r--board/sandbox/hostfile.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/board/sandbox/hostfile.c b/board/sandbox/hostfile.c
index f91601febb..ad625d7a6e 100644
--- a/board/sandbox/hostfile.c
+++ b/board/sandbox/hostfile.c
@@ -1,5 +1,5 @@
/*
* hostfile.c - use files from the host to simalute U-Boot devices
*
* Copyright (c) 2007 Sascha Hauer <s.hauer@pengutronix.de>, Pengutronix
*
@@ -97,7 +97,7 @@ static int hf_init(void)
device_initcall(hf_init);
-int u_boot_register_filedev(struct hf_platform_data *hf)
+int barebox_register_filedev(struct hf_platform_data *hf)
{
struct device_d *dev;
@@ -1,5 +1,5 @@
/*
- * hostfile.c - use files from the host to simalute U-Boot devices
+ * hostfile.c - use files from the host to simalute barebox devices
*
* Copyright (c) 2007 Sascha Hauer <s.hauer@pengutronix.de>, Pengutronix